@@ -17,9 +17,15 @@ class QuickbaseParameter:
     def build(self):
         return 'Default String'
 
+    def to_json(self):
+        return self.build()
+
     def __str__(self):
         return self.build()
 
+    def __repr__(self):
+        return self.build()
+
 
 class Where(QuickbaseParameter):
     def __init__(self, fid: any, operator: str, value: any, **kwargs):
